<?php
namespace filebase\system\event\listener;
use wcf\system\event\listener\IParameterizedEventListener;
use wcf\system\exception\NamedUserException;
use wcf\system\user\jcoins\UserJCoinsStatementHandler;
use wcf\system\WCF;

/**
 * JCoins download file listener.
 *
 * @author		2017-2022 Zaydowicz
 * @license		GNU Lesser General Public License <http://opensource.org/licenses/lgpl-license.php>
 * @package		de.wcflabs.filebase.jcoins
 */
class JCoinsDownloadFileListener implements IParameterizedEventListener {
	/**
	 * @inheritdoc
	 */
	public function execute($eventObj, $className, $eventName, array &$parameters) {
		if (!MODULE_JCOINS) return;
		
		if ($eventObj->file->userID == WCF::getUser()->userID) return;
		if (!WCF::getUser()->userID) return;
		
		// no JCoins for purchased file
		if ($eventObj->file->isPurchasable && $eventObj->file->isCustomer()) return;
		
		if ($eventName == 'readData' && !JCOINS_ALLOW_NEGATIVE) {
			$statement = UserJCoinsStatementHandler::getInstance()->getStatementProcessorInstance('de.wcflabs.jcoins.statement.download.user');
			if ($statement->calculateAmount() < 0 && ($statement->calculateAmount() * -1) > WCF::getUser()->jCoinsAmount) {
				throw new NamedUserException(WCF::getLanguage()->getDynamicVariable('wcf.jcoins.amount.tooLow'));
			}
		}
		
		if ($eventName == 'show') {
			UserJCoinsStatementHandler::getInstance()->create('de.wcflabs.jcoins.statement.download', $eventObj->file);
			UserJCoinsStatementHandler::getInstance()->create('de.wcflabs.jcoins.statement.download.user', $eventObj->file,['userID' => WCF::getUser()->userID]);
		}
	}
}
