<?php
namespace filebase\system\event\listener;
use filebase\data\file\File;
use wcf\data\object\type\ObjectTypeCache;
use wcf\system\event\listener\IParameterizedEventListener;
use wcf\system\user\jcoins\UserJCoinsStatementHandler;
use wcf\util\OptionUtil;

/**
 * JCoins file payment listener.
 *
 * @author		2017-2022 Zaydowicz
 * @license		GNU Lesser General Public License <http://opensource.org/licenses/lgpl-license.php>
 * @package		de.wcflabs.filebase.jcoins
 */
class JCoinsFilePaymentListener implements IParameterizedEventListener {
	/**
	 * @inheritdoc
	 */
	public function execute($eventObj, $className, $eventName, array &$parameters) {
		if (!MODULE_JCOINS || !JCOINS_FILEBASE_USER_PAYOUT || $eventObj->getActionName() != 'create') return;
		
		$actionParameters = $eventObj->getParameters();
		
		if ($actionParameters['data']['logMessage'] != 'payment completed') return; 
		if ($actionParameters['data']['paymentMethodObjectTypeID'] != ObjectTypeCache::getInstance()->getObjectTypeIDByName('com.woltlab.wcf.payment.method', 'com.woltlab.wcf.payment.method.jcoins')) return;
		
		$file = new File($actionParameters['data']['fileID']);
		
		$jCoinsCurrency = OptionUtil::parseSelectOptions(JCOINS_CURRENCY_TO_COINS);
		
		if (!isset($jCoinsCurrency[$file->currency])) {
			throw new SystemException("Unknown currency for JCoins");
		}
		
		$conversion = floatval($jCoinsCurrency[$file->currency]);
		$amount = round($conversion * $file->getPrice());
		
		UserJCoinsStatementHandler::getInstance()->create('de.wcflabs.jcoins.statement.filePayment', $file, ['amount' => $amount]);
	}
}
