<?php
namespace filebase\system\event\listener;
use filebase\data\file\version\review\FileVersionReviewAction;
use wcf\system\event\listener\IParameterizedEventListener;
use wcf\system\user\jcoins\UserJCoinsStatementHandler;

/**
 * JCoins file review listener.
 *
 * @author		2020-2022 Zaydowicz
 * @license		GNU Lesser General Public License <http://opensource.org/licenses/lgpl-license.php>
 * @package		de.wcflabs.filebase.jcoins
 */
class JCoinsFileReviewListener implements IParameterizedEventListener {
	/**
	 * @inheritdoc
	 */
	public function execute($eventObj, $className, $eventName, array &$parameters) {
		if (!MODULE_JCOINS) return;
		
		if ($eventObj instanceof FileVersionReviewAction) {
			switch ($eventObj->getActionName()) {
				case 'triggerPublication':
					foreach ($eventObj->getObjects() as $object) {
						if ($object->userID) {
							UserJCoinsStatementHandler::getInstance()->create('de.wcflabs.jcoins.statement.file.review', $object->getDecoratedObject());
						}
					}
					break;
					
					// 'toggle->enable' calls triggerPublication
					
				case 'toggle':
					foreach ($eventObj->getObjects() as $object) {
						if (!$object->isDisabled && $object->userID) {
							UserJCoinsStatementHandler::getInstance()->revoke('de.wcflabs.jcoins.statement.file.review', $object->getDecoratedObject());
						}
					}
					break;
					
				case 'delete':
					foreach ($eventObj->getObjects() as $object) {
						if (!$object->isDisabled && $object->userID) {
							UserJCoinsStatementHandler::getInstance()->revoke('de.wcflabs.jcoins.statement.file.review', $object->getDecoratedObject());
						}
					}
					break;
			}
		}
	}
}
